interface NodePlayer {
  /**
   * 自动测试浏览器是否支持MSE硬件解码播放
   * 如不支持，仍然使用软解码。
   * 紧随 new 后调用，不调用则只使用软解。
   * 注意：使用MSE后不支持累积延迟消除
   */
  useMSE(): void;

  /**
   * 绑定视图id
   * @param viewId canvas视图id
   */
  setView(viewId: string): void;

  /**
   * 设置视频缩放模式
   * 当视频分辨率比例与canvas显示区域比例不同时,缩放效果不同:
   * 0 视频画面完全填充canvas区域,画面会被拉伸
   * 1 视频画面做等比缩放后,对齐canvas区域,画面不被拉伸,但有黑边
   * 2 视频画面做等比缩放后,完全填充canvas区域,画面不被拉伸,没有黑边,但画面显示不全
   * 注意：只在软解时有效
   * @param mode 缩放模式
   */
  setScaleMode(mode: number): void;

  /**
   * 设置最大缓冲时长，单位毫秒
   * 注意：只在软解时有效
   * @param bufferTime
   */
  setBufferTime(bufferTime: number): void;

  /**
   * 设置音量大小，取值0.0 — 1.0
   * 当为0.0时，完全无声
   * 当为1.0时，最大音量，默认值
   * @param volume 音量大小,浮点类型
   */
  setVolume(volume: number): void;

  /**
   * 重置视图大小,将自动改变标签的高宽和css高宽
   * @param width 新视频区域宽
   * @param height 新视频区域高
   */
  resizeView(width: number, height: number): void;

  /**
   * 开始播放
   * @param url http-flv,ws-flv 直播地址
   */
  start(url: string): void;

  /**
   * 停止播放
   */
  stop(): void;

  /**
   * 绑定事件监听器
   * @param event 事件
   * @param handler 处理器
   *
   * 'start'事件 当连接成功并收到数据
   * 'stop' 事件 当本地stop或远端断开连接
   * 'error'事件 当连接错误或播放中发生错误
   */
  on(event: string, listener: (...args: any[]) => void): void;
}
